==> haskell-isocline-1.0.9-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-isocline.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 isocline
version:              1.0.9
visibility:           public
id:                   isocline-1.0.9-aBs81QHGNX3YvnPk3B22g
key:                  isocline-1.0.9-aBs81QHGNX3YvnPk3B22g
license:              MIT
maintainer:           daan@effp.org
author:               Daan Leijen
homepage:             https://github.com/daanx/isocline#readme
synopsis:             A portable alternative to GNU Readline
description:
    ![logo](https://raw.githubusercontent.com/daanx/isocline/main/doc/isocline-inline.svg) A Haskell wrapper around the [Isocline C library](https://github.com/daanx/isocline#readme) which can provide an alternative to GNU Readline. (The Isocline library is included whole and there are no runtime dependencies).
    Please see the [readme](https://github.com/daanx/isocline/haskell#readme) on GitHub for more information.

category:             console
abi:                  5610a65b129e67d6f3a8d03c13956f2a
exposed:              True
exposed-modules:      System.Console.Isocline
hidden-modules:       Paths_isocline
import-dirs:          /usr/lib/ghc-9.0.2/site-local/isocline-1.0.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/isocline-1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isocline
hs-libraries:         HSisocline-1.0.9-aBs81QHGNX3YvnPk3B22g
depends:              base-4.15.1.0 bytestring-0.10.12.1 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-isocline/html/isocline.haddock
haddock-html:         /usr/share/doc/haskell-isocline/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-isocline-1.0.9-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-isocline.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 isocline
version:              1.0.9
visibility:           public
id:                   isocline-1.0.9-2dBQZhT1SqR1bCMBoLzGES
key:                  isocline-1.0.9-2dBQZhT1SqR1bCMBoLzGES
license:              MIT
maintainer:           daan@effp.org
author:               Daan Leijen
homepage:             https://github.com/daanx/isocline#readme
synopsis:             A portable alternative to GNU Readline
description:
    ![logo](https://raw.githubusercontent.com/daanx/isocline/main/doc/isocline-inline.svg) A Haskell wrapper around the [Isocline C library](https://github.com/daanx/isocline#readme) which can provide an alternative to GNU Readline. (The Isocline library is included whole and there are no runtime dependencies).
    Please see the [readme](https://github.com/daanx/isocline/haskell#readme) on GitHub for more information.

category:             console
abi:                  672698b4e55009d12a387af4984681a6
exposed:              True
exposed-modules:      System.Console.Isocline
hidden-modules:       Paths_isocline
import-dirs:          /usr/lib/ghc-9.2.8/site-local/isocline-1.0.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/isocline-1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isocline
hs-libraries:         HSisocline-1.0.9-2dBQZhT1SqR1bCMBoLzGES
depends:              base-4.16.4.0 bytestring-0.11.4.0 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-isocline/html/isocline.haddock
haddock-html:         /usr/share/doc/haskell-isocline/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
